@@ -1,9 +1,8 @@
 # $Author: ddumont $
-# $Date: 2008-03-20 14:26:46 +0100 (Thu, 20 Mar 2008) $
-# $Name: not supported by cvs2svn $
-# $Revision: 552 $
+# $Date: 2008-04-15 14:14:43 +0200 (Tue, 15 Apr 2008) $
+# $Revision: 609 $
 
-#    Copyright (c) 2007 Dominique Dumont.
+#    Copyright (c) 2007-2008 Dominique Dumont.
 #
 #    This file is part of Config-Model-Itself.
 #
@@ -32,17 +31,17 @@
        'follow' 
        => {
 	   type => 'hash',
-	   cargo_type => 'leaf',
 	   index_type =>'string',
-	   cargo_args => { value_type => 'uniline' } ,
+	   cargo => { type => 'leaf', value_type => 'uniline' } ,
 	   description => 'Specify with a path the configuration element that will drive the warp , i.e .the elements that control the property change. These a specified using a variable name (used in the "rules" formula) and a path to fetch the actual value. Example $country => " ! country"',
 	  },
        'rules' => {
 		   type => 'hash',
 		   ordered => 1,
 		   index_type => 'string',
-		   cargo_type => 'node',
-		   config_class_name => 'Itself::WarpableElement' ,
+		   cargo => { type => 'node',
+			      config_class_name => 'Itself::WarpOnlyElement' ,
+			    },
 		   description => 'Specify several test (as formula using the variables defined in "follow" element) to try in sequences and their associated effects',
 		  },
       ],
